@@ -23,7 +23,9 @@ extern "C" {
 #include "re_aes.h"
 #include "re_base64.h"
 #include "re_bfcp.h"
+#include "re_btrace.h"
 #include "re_conf.h"
+#include "re_convert.h"
 #include "re_crc32.h"
 #include "re_dns.h"
 #include "re_hash.h"
@@ -32,15 +34,15 @@ extern "C" {
 #include "re_httpauth.h"
 #include "re_ice.h"
 #include "re_jbuf.h"
-#include "re_lock.h"
+#include "re_net.h"
 #include "re_main.h"
 #include "re_md5.h"
 #include "re_mem.h"
 #include "re_mod.h"
 #include "re_mqueue.h"
-#include "re_net.h"
 #include "re_odict.h"
 #include "re_json.h"
+#include "re_rtmp.h"
 #include "re_rtp.h"
 #include "re_sdp.h"
 #include "re_uri.h"
@@ -49,16 +51,20 @@ extern "C" {
 #include "re_sipreg.h"
 #include "re_sipsess.h"
 #include "re_stun.h"
-#include "re_natbd.h"
 #include "re_srtp.h"
 #include "re_sys.h"
 #include "re_tcp.h"
 #include "re_telev.h"
+#include "re_thread.h"
 #include "re_tmr.h"
+#include "re_trace.h"
 #include "re_tls.h"
 #include "re_turn.h"
 #include "re_udp.h"
 #include "re_websock.h"
+#include "re_shim.h"
+#include "re_trice.h"
+#include "re_pcp.h"
 
 #ifdef __cplusplus
 }
