@@ -4,6 +4,8 @@
  * Copyright (C) 2010 Creytiv.com
  */
 
+/* forward declarations */
+struct tls;
 
 /** HTTP Header ID (perfect hash value) */
 enum http_hdrid {
@@ -87,6 +89,25 @@ struct http_msg {
 	uint32_t clen;         /**< Content length                         */
 };
 
+
+struct http_uri {
+	struct pl scheme;
+	struct pl host;
+	struct pl port;
+	struct pl path;
+};
+
+int http_uri_decode(struct http_uri *hu, const struct pl *uri);
+
+
+/** Http Client configuration */
+struct http_conf {
+	uint32_t conn_timeout;  /* in [ms] */
+	uint32_t recv_timeout;  /* in [ms] */
+	uint32_t idle_timeout;  /* in [ms] */
+};
+
+
 typedef bool(http_hdr_h)(const struct http_hdr *hdr, void *arg);
 
 int  http_msg_decode(struct http_msg **msgp, struct mbuf *mb, bool req);
@@ -125,11 +146,31 @@ typedef void (http_conn_h)(struct tcp_conn *tc, struct tls_conn *sc,
 			   void *arg);
 
 int http_client_alloc(struct http_cli **clip, struct dnsc *dnsc);
+int http_client_set_config(struct http_cli *cli, struct http_conf *conf);
 int http_request(struct http_req **reqp, struct http_cli *cli, const char *met,
 		 const char *uri, http_resp_h *resph, http_data_h *datah,
 		 void *arg, const char *fmt, ...);
 void http_req_set_conn_handler(struct http_req *req, http_conn_h *connh);
+void http_client_set_laddr(struct http_cli *cli, const struct sa *addr);
+void http_client_set_laddr6(struct http_cli *cli, const struct sa *addr);
 
+#ifdef USE_TLS
+int http_client_set_tls(struct http_cli *cli, struct tls *tls);
+int http_client_get_tls(struct http_cli *cli, struct tls **tls);
+int http_client_add_ca(struct http_cli *cli, const char *tls_ca);
+int http_client_add_capem(struct http_cli *cli, const char *capem);
+int http_client_add_crlpem(struct http_cli *cli, const char *pem);
+int http_client_set_tls_hostname(struct http_cli *cli,
+				 const struct pl *hostname);
+int http_client_set_cert(struct http_cli *cli, const char *path);
+int http_client_set_certpem(struct http_cli *cli, const char *pem);
+int http_client_set_key(struct http_cli *cli, const char *path);
+int http_client_set_keypem(struct http_cli *cli, const char *pem);
+
+int http_client_set_session_reuse(struct http_cli *cli, bool enabled);
+int http_client_set_tls_min_version(struct http_cli *cli, int version);
+int http_client_set_tls_max_version(struct http_cli *cli, int version);
+#endif
 
 /* Server */
 struct http_sock;
@@ -146,6 +187,7 @@ struct tcp_sock *http_sock_tcp(struct http_sock *sock);
 const struct sa *http_conn_peer(const struct http_conn *conn);
 struct tcp_conn *http_conn_tcp(struct http_conn *conn);
 struct tls_conn *http_conn_tls(struct http_conn *conn);
+void http_conn_reset_timeout(struct http_conn *conn);
 void http_conn_close(struct http_conn *conn);
 int  http_reply(struct http_conn *conn, uint16_t scode, const char *reason,
 		const char *fmt, ...);
@@ -169,3 +211,28 @@ bool http_auth_check(const struct pl *hval, const struct pl *method,
 bool http_auth_check_request(const struct http_msg *msg,
 			     struct http_auth *auth,
 			     http_auth_h *authh, void *arg);
+
+/* http_reqconn - HTTP request connection */
+struct http_reqconn;
+int http_reqconn_alloc(struct http_reqconn **pconn,
+		struct http_cli *client,
+		http_resp_h *resph, http_data_h *datah, void* arg);
+int http_reqconn_set_auth(struct http_reqconn *conn, const struct pl *user,
+		const struct pl *pass);
+int http_reqconn_set_bearer(struct http_reqconn *conn,
+		const struct pl *bearer);
+int http_reqconn_set_authtoken(struct http_reqconn *conn,
+		const struct pl *token);
+int http_reqconn_set_tokentype(struct http_reqconn *conn,
+		const struct pl *tokentype);
+int http_reqconn_set_method(struct http_reqconn *conn, const struct pl *met);
+int http_reqconn_set_body(struct http_reqconn *conn, const struct pl *body);
+int http_reqconn_set_ctype(struct http_reqconn *conn, const struct pl *ctype);
+int http_reqconn_add_header(struct http_reqconn *conn,
+		const struct pl *header);
+int http_reqconn_clr_header(struct http_reqconn *conn);
+int http_reqconn_send(struct http_reqconn *conn, const struct pl *uri);
+#ifdef USE_TLS
+int http_reqconn_set_tls_hostname(struct http_reqconn *conn,
+		const struct pl *hostname);
+#endif
