@@ -5,12 +5,6 @@
  */
 
 
-/** ICE mode */
-enum ice_mode {
-	ICE_MODE_FULL,
-	ICE_MODE_LITE
-};
-
 /** ICE Role */
 enum ice_role {
 	ICE_ROLE_UNKNOWN = 0,
@@ -24,12 +18,6 @@ enum ice_compid {
 	ICE_COMPID_RTCP = 2
 };
 
-/** ICE Nomination */
-enum ice_nomination {
-	ICE_NOMINATION_REGULAR = 0,
-	ICE_NOMINATION_AGGRESSIVE
-};
-
 /** ICE Candidate type */
 enum ice_cand_type {
 	ICE_CAND_TYPE_HOST,   /**< Host candidate             */
@@ -55,12 +43,12 @@ enum ice_candpair_state {
 };
 
 struct ice;
+struct ice_cand;
 struct icem;
 struct turnc;
 
 /** ICE Configuration */
 struct ice_conf {
-	enum ice_nomination nom;  /**< Nomination algorithm        */
 	uint32_t rto;             /**< STUN Retransmission TimeOut */
 	uint32_t rc;              /**< STUN Retransmission Count   */
 	bool debug;               /**< Enable ICE debugging        */
@@ -70,8 +58,7 @@ typedef void (ice_connchk_h)(int err, bool update, void *arg);
 
 
 /* ICE Media */
-int  icem_alloc(struct icem **icemp, enum ice_mode mode,
-		enum ice_role role, int proto, int layer,
+int  icem_alloc(struct icem **icemp, enum ice_role role, int proto, int layer,
 		uint64_t tiebrk, const char *lufrag, const char *lpwd,
 		ice_connchk_h *chkh, void *arg);
 struct ice_conf *icem_conf(struct icem *icem);
@@ -83,7 +70,6 @@ int  icem_comp_add(struct icem *icem, unsigned compid, void *sock);
 int  icem_cand_add(struct icem *icem, unsigned compid, uint16_t lprio,
 		   const char *ifname, const struct sa *addr);
 
-int  icem_lite_set_default_candidates(struct icem *icem);
 bool icem_verify_support(struct icem *icem, unsigned compid,
 			 const struct sa *raddr);
 int  icem_conncheck_start(struct icem *icem);
@@ -100,6 +86,10 @@ struct list *icem_checkl(const struct icem *icem);
 struct list *icem_validl(const struct icem *icem);
 const struct sa *icem_cand_default(struct icem *icem, unsigned compid);
 const struct sa *icem_selected_laddr(const struct icem *icem, unsigned compid);
+const struct ice_cand *icem_selected_lcand(const struct icem *icem,
+				unsigned compid);
+const struct ice_cand *icem_selected_rcand(const struct icem *icem,
+				unsigned compid);
 void ice_candpair_set_states(struct icem *icem);
 void icem_cand_redund_elim(struct icem *icem);
 int  icem_comps_set_default_cand(struct icem *icem);
@@ -108,7 +98,6 @@ int icem_set_turn_client(struct icem *icem, unsigned compid,
 			 struct turnc *turnc);
 
 
-struct ice_cand;
 bool ice_remotecands_avail(const struct icem *icem);
 int  ice_cand_encode(struct re_printf *pf, const struct ice_cand *cand);
 int  ice_remotecands_encode(struct re_printf *pf, const struct icem *icem);
@@ -119,6 +108,7 @@ int icem_lcand_add(struct icem *icem, struct ice_cand *base,
 		   const struct sa *addr);
 struct ice_cand *icem_lcand_base(struct ice_cand *lcand);
 const struct sa *icem_lcand_addr(const struct ice_cand *cand);
+enum ice_cand_type icem_cand_type(const struct ice_cand *cand);
 
 
 extern const char ice_attr_cand[];
@@ -135,7 +125,7 @@ const char    *ice_role2name(enum ice_role role);
 const char    *ice_candpair_state2name(enum ice_candpair_state st);
 
 
-uint32_t ice_cand_calc_prio(enum ice_cand_type type, uint16_t local,
+uint32_t ice_cand_calc_prio(enum ice_cand_type type, uint16_t lpref,
 			    unsigned compid);
 
 
