@@ -4,6 +4,7 @@
  * Copyright (C) 2010 Creytiv.com
  */
 
+struct re;
 
 enum {
 #ifndef FD_READ
@@ -32,8 +33,8 @@ typedef void (fd_h)(int flags, void *arg);
 typedef void (re_signal_h)(int sig);
 
 
-int   fd_listen(int fd, int flags, fd_h *fh, void *arg);
-void  fd_close(int fd);
+int   fd_listen(re_sock_t fd, int flags, fd_h *fh, void *arg);
+void  fd_close(re_sock_t fd);
 int   fd_setsize(int maxfds);
 void  fd_debug(void);
 
@@ -43,11 +44,17 @@ void  libre_close(void);
 int   re_main(re_signal_h *signalh);
 void  re_cancel(void);
 int   re_debug(struct re_printf *pf, void *unused);
+int   re_nfds(void);
+
+int  re_alloc(struct re **rep);
+int  re_thread_attach(struct re *re);
+void re_thread_detach(void);
 
 int  re_thread_init(void);
 void re_thread_close(void);
 void re_thread_enter(void);
 void re_thread_leave(void);
+int  re_thread_check(void);
 
 void re_set_mutex(void *mutexp);
 
@@ -64,6 +71,7 @@ enum poll_method {
 };
 
 int              poll_method_set(enum poll_method method);
+enum poll_method poll_method_get(void);
 enum poll_method poll_method_best(void);
 const char      *poll_method_name(enum poll_method method);
 int poll_method_type(enum poll_method *method, const struct pl *name);
