@@ -4,6 +4,8 @@
  * Copyright (C) 2010 Creytiv.com
  */
 
+/* forward declarations */
+struct tls;
 
 enum {
 	SIP_PORT     = 5060,
@@ -16,6 +18,9 @@ enum sip_transp {
 	SIP_TRANSP_UDP = 0,
 	SIP_TRANSP_TCP,
 	SIP_TRANSP_TLS,
+	SIP_TRANSP_WS,
+	SIP_TRANSP_WSS,
+
 	SIP_TRANSPC,
 };
 
@@ -130,6 +135,13 @@ enum sip_hdrid {
 };
 
 
+enum rel100_mode {
+	REL100_DISABLED = 0,
+	REL100_ENABLED = 1,
+	REL100_REQUIRED = 2,
+};
+
+
 enum {
 	SIP_T1 =  500,
 	SIP_T2 = 4000,
@@ -171,6 +183,13 @@ struct sip_cseq {
 	uint32_t num;
 };
 
+/** SIP RAck header (RFC 3262) */
+struct sip_rack {
+	struct pl met;
+	uint32_t rel_seq;
+	uint32_t cseq;
+};
+
 /** SIP Header */
 struct sip_hdr {
 	struct le le;          /**< Linked-list element    */
@@ -195,6 +214,8 @@ struct sip_msg {
 	struct sip_taddr to;   /**< Parsed To header                     */
 	struct sip_taddr from; /**< Parsed From header                   */
 	struct sip_cseq cseq;  /**< Parsed CSeq header                   */
+	struct sip_rack rack;  /**< Parsed RAck header (RFC 3262)        */
+	uint32_t rel_seq;      /**< RSeq number (RFC 3262)               */
 	struct msg_ctype ctyp; /**< Content Type                         */
 	struct pl callid;      /**< Cached Call-ID header                */
 	struct pl maxfwd;      /**< Cached Max-Forwards header           */
@@ -221,6 +242,14 @@ struct sip_contact {
 	enum sip_transp tp;
 };
 
+/** SIP connection config */
+struct sip_conncfg {
+	struct le he;
+	struct sa paddr;
+
+	uint16_t srcport;
+};
+
 struct sip;
 struct sip_lsnr;
 struct sip_request;
@@ -231,8 +260,9 @@ struct sip_keepalive;
 struct dnsc;
 
 typedef bool(sip_msg_h)(const struct sip_msg *msg, void *arg);
-typedef int(sip_send_h)(enum sip_transp tp, const struct sa *src,
-			const struct sa *dst, struct mbuf *mb, void *arg);
+typedef int(sip_send_h)(enum sip_transp tp, struct sa *src,
+			const struct sa *dst, struct mbuf *mb,
+			struct mbuf **contp, void *arg);
 typedef void(sip_resp_h)(int err, const struct sip_msg *msg, void *arg);
 typedef void(sip_cancel_h)(void *arg);
 typedef void(sip_exit_h)(void *arg);
@@ -242,6 +272,11 @@ typedef bool(sip_hdr_h)(const struct sip_hdr *hdr, const struct sip_msg *msg,
 			void *arg);
 typedef void(sip_keepalive_h)(int err, void *arg);
 
+#define LIBRE_HAVE_SIPTRACE 1
+typedef void(sip_trace_h)(bool tx, enum sip_transp tp,
+			  const struct sa *src, const struct sa *dst,
+			  const uint8_t *pkt, size_t len, void *arg);
+
 
 /* sip */
 int  sip_alloc(struct sip **sipp, struct dnsc *dnsc, uint32_t ctsz,
@@ -253,19 +288,29 @@ int  sip_listen(struct sip_lsnr **lsnrp, struct sip *sip, bool req,
 int  sip_debug(struct re_printf *pf, const struct sip *sip);
 int  sip_send(struct sip *sip, void *sock, enum sip_transp tp,
 	      const struct sa *dst, struct mbuf *mb);
+void sip_set_trace_handler(struct sip *sip, sip_trace_h *traceh);
 
 
 /* transport */
 int  sip_transp_add(struct sip *sip, enum sip_transp tp,
 		    const struct sa *laddr, ...);
+int  sip_transp_add_websock(struct sip *sip, enum sip_transp tp,
+			    const struct sa *laddr,
+			    bool server, const char *cert, struct tls *tls);
+int  sip_transp_add_ccert(struct sip *sip, const struct uri *uri,
+			  const char *ccertfile);
 void sip_transp_flush(struct sip *sip);
 bool sip_transp_isladdr(const struct sip *sip, enum sip_transp tp,
 			const struct sa *laddr);
 const char *sip_transp_name(enum sip_transp tp);
 const char *sip_transp_param(enum sip_transp tp);
+enum sip_transp sip_transp_decode(const struct pl *pl);
 uint16_t sip_transp_port(enum sip_transp tp, uint16_t port);
 int  sip_transp_laddr(struct sip *sip, struct sa *laddr, enum sip_transp tp,
 		      const struct sa *dst);
+int  sip_transp_set_default(struct sip *sip, enum sip_transp tp);
+void sip_transp_rmladdr(struct sip *sip, const struct sa *laddr);
+int  sip_settos(struct sip *sip, uint8_t tos);
 
 
 /* request */
@@ -309,7 +354,10 @@ void sip_reply_addr(struct sa *addr, const struct sip_msg *msg, bool rport);
 int  sip_auth_authenticate(struct sip_auth *auth, const struct sip_msg *msg);
 int  sip_auth_alloc(struct sip_auth **authp, sip_auth_h *authh,
 		    void *arg, bool ref);
+
 void sip_auth_reset(struct sip_auth *auth);
+int  sip_auth_encode(struct mbuf *mb, struct sip_auth *auth, const char *met,
+		     const char *uri);
 
 
 /* contact */
@@ -331,7 +379,10 @@ int  sip_dialog_fork(struct sip_dialog **dlgp, struct sip_dialog *odlg,
 int  sip_dialog_update(struct sip_dialog *dlg, const struct sip_msg *msg);
 bool sip_dialog_rseq_valid(struct sip_dialog *dlg, const struct sip_msg *msg);
 const char *sip_dialog_callid(const struct sip_dialog *dlg);
+int  sip_dialog_set_callid(struct sip_dialog *dlg, const char *callid);
+const char *sip_dialog_uri(const struct sip_dialog *dlg);
 uint32_t sip_dialog_lseq(const struct sip_dialog *dlg);
+enum sip_transp sip_dialog_tp(const struct sip_dialog *dlg);
 bool sip_dialog_established(const struct sip_dialog *dlg);
 bool sip_dialog_cmp(const struct sip_dialog *dlg, const struct sip_msg *msg);
 bool sip_dialog_cmp_half(const struct sip_dialog *dlg,
@@ -362,9 +413,14 @@ void sip_msg_dump(const struct sip_msg *msg);
 int sip_addr_decode(struct sip_addr *addr, const struct pl *pl);
 int sip_via_decode(struct sip_via *via, const struct pl *pl);
 int sip_cseq_decode(struct sip_cseq *cseq, const struct pl *pl);
+int sip_rack_decode(struct sip_rack *rack, const struct pl *pl);
 
 
 /* keepalive */
 int sip_keepalive_start(struct sip_keepalive **kap, struct sip *sip,
 			const struct sip_msg *msg, uint32_t interval,
 			sip_keepalive_h *kah, void *arg);
+
+/* sip_conncfg */
+int sip_conncfg_set(struct sip *sip, const struct sa *paddr,
+		    const struct sip_conncfg conncfg);
