@@ -6,90 +6,24 @@
 
 #include <sys/types.h>
 
+#ifdef __cplusplus
+#define restrict
+#endif
+
 #ifdef _MSC_VER
 #include <stdlib.h>
+
+#include <BaseTsd.h>
+typedef SSIZE_T ssize_t;
+
 #endif
 
 /*
- * Basic integral types from C99
+ * Basic integral types and boolean from C99
  */
-
-#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
-#else
+#include <stdbool.h>
 
-#ifndef __int8_t_defined
-#define __int8_t_defined
-
-/* Hack for OpenBSD */
-#ifndef __BIT_TYPES_DEFINED__
-
-#if defined(_CHAR_IS_SIGNED)
-typedef char                    int8_t;
-#elif defined(__STDC__)
-typedef signed char             int8_t;
-#else
-typedef char                    int8_t;
-#endif
-
-typedef signed short int          int16_t;
-typedef signed int                int32_t;
-typedef signed long long int      int64_t;
-
-#ifndef __uint32_t_defined
-#define __uint32_t_defined
-typedef unsigned char             uint8_t;
-typedef unsigned short int        uint16_t;
-typedef unsigned int              uint32_t;
-typedef unsigned long long int    uint64_t;
-#endif
-
-#endif /* __BIT_TYPES_DEFINED__ */
-
-#endif /* __int8_t_defined */
-#ifndef __ssize_t_defined
-typedef long     ssize_t;
-#define __ssize_t_defined
-#endif
-
-
-#ifndef WIN32
-typedef uint32_t socklen_t;
-#endif
-#endif
-
-
-/*
- * Hack for Solaris which does not define int64_t/uint64_t for strict ANSI C
- */
-#ifdef SOLARIS
-#if !(__STDC__ - 0 == 0 && !defined(_NO_LONGLONG))
-typedef signed long long int      int64_t;
-typedef unsigned long long int    uint64_t;
-#endif
-#endif
-
-
-/*
- * Boolean type
- * see http://www.opengroup.org/onlinepubs/000095399/basedefs/stdbool.h.html
- *     www.gnu.org/software/autoconf/manual/html_node/Particular-Headers.html
- */
-#ifdef HAVE_STDBOOL_H
-# include <stdbool.h>
-#else
-# ifndef HAVE__BOOL
-#  ifdef __cplusplus
-typedef bool _Bool;
-#  else
-#   define _Bool signed char
-#  endif
-# endif
-# define bool _Bool
-# define false 0
-# define true 1
-# define __bool_true_false_are_defined 1
-#endif
 
 /* Needed for MS compiler */
 #ifdef _MSC_VER
@@ -115,6 +49,8 @@ typedef bool _Bool;
 /** Align a value to the boundary of mask */
 #define ALIGN_MASK(x, mask)    (((x)+(mask))&~(mask))
 
+/** Check alignment of pointer (p) and byte count (c) **/
+#define is_aligned(p, c) (((uintptr_t)(const void *)(p)) % (c) == 0)
 
 /** Get the minimal value */
 #undef MIN
@@ -291,6 +227,10 @@ typedef bool _Bool;
 #define ENOSR 218
 #endif
 
+/** Key was rejected by service */
+#ifndef EKEYREJECTED
+#define EKEYREJECTED 129
+#endif
 
 /*
  * Any C compiler conforming to C99 or later MUST support __func__
@@ -300,3 +240,15 @@ typedef bool _Bool;
 #else
 #define __REFUNC__ __FUNCTION__
 #endif
+
+/*
+ * Give the compiler a hint which branch is "likely" or "unlikely" (inspired
+ * by linux kernel and C++20/C2X)
+ */
+#ifdef __GNUC__
+#define likely(x)       __builtin_expect(!!(x), 1)
+#define unlikely(x)     __builtin_expect(!!(x), 0)
+#else
+#define likely(x) x
+#define unlikely(x) x
+#endif
